@@ -2,6 +2,8 @@
 Rate limiting with commonly used storage backends
 """
 
+from __future__ import annotations
+
 from . import _version, aio, storage, strategies
 from .limits import (
     RateLimitItem,
@@ -16,18 +18,18 @@ from .util import WindowStats, parse, parse_many
 
 __all__ = [
     "RateLimitItem",
-    "RateLimitItemPerYear",
-    "RateLimitItemPerMonth",
     "RateLimitItemPerDay",
     "RateLimitItemPerHour",
     "RateLimitItemPerMinute",
+    "RateLimitItemPerMonth",
     "RateLimitItemPerSecond",
+    "RateLimitItemPerYear",
+    "WindowStats",
     "aio",
-    "storage",
-    "strategies",
     "parse",
     "parse_many",
-    "WindowStats",
+    "storage",
+    "strategies",
 ]
 
-__version__ = _version.get_versions()["version"]  # type: ignore
+__version__ = _version.get_versions()["version"]
