@@ -1,14 +1,19 @@
+from __future__ import annotations
+
 import time
 import urllib.parse
-from typing import TYPE_CHECKING, Optional, Tuple, Type, Union
+
+from deprecated.sphinx import deprecated
 
 from limits.errors import ConcurrentUpdateError
 from limits.storage.base import Storage
+from limits.typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     import etcd3
 
 
+@deprecated(version="4.4")
 class EtcdStorage(Storage):
     """
     Rate limit storage with etcd as backend.
@@ -26,6 +31,7 @@ class EtcdStorage(Storage):
         self,
         uri: str,
         max_retries: int = MAX_RETRIES,
+        wrap_exceptions: bool = False,
         **options: str,
     ) -> None:
         """
@@ -33,21 +39,24 @@ class EtcdStorage(Storage):
          ``etcd://host:port``,
         :param max_retries: Maximum number of attempts to retry
          in the case of concurrent updates to a rate limit key
+        :param wrap_exceptions: Whether to wrap storage exceptions in
+         :exc:`limits.errors.StorageError` before raising it.
         :param options: all remaining keyword arguments are passed
          directly to the constructor of :class:`etcd3.Etcd3Client`
         :raise ConfigurationError: when :pypi:`etcd3` is not available
         """
         parsed = urllib.parse.urlparse(uri)
         self.lib = self.dependencies["etcd3"].module
-        self.storage: "etcd3.Etcd3Client" = self.lib.client(
+        self.storage: etcd3.Etcd3Client = self.lib.client(
             parsed.hostname, parsed.port, **options
         )
         self.max_retries = max_retries
+        super().__init__(uri, wrap_exceptions=wrap_exceptions)
 
     @property
     def base_exceptions(
         self,
-    ) -> Union[Type[Exception], Tuple[Type[Exception], ...]]:  # pragma: no cover
+    ) -> type[Exception] | tuple[type[Exception], ...]:  # pragma: no cover
         return self.lib.Etcd3Exception  # type: ignore[no-any-return]
 
     def prefixed_key(self, key: str) -> bytes:
@@ -110,12 +119,11 @@ class EtcdStorage(Storage):
                 return int(amount)
         return 0
 
-    def get_expiry(self, key: str) -> int:
+    def get_expiry(self, key: str) -> float:
         value, _ = self.storage.get(self.prefixed_key(key))
         if value:
-            window_end = float(value.split(b":")[1])
-            return int(window_end)
-        return int(time.time())
+            return float(value.split(b":")[1])
+        return time.time()
 
     def check(self) -> bool:
         try:
@@ -124,7 +132,7 @@ class EtcdStorage(Storage):
         except:  # noqa
             return False
 
-    def reset(self) -> Optional[int]:
+    def reset(self) -> int | None:
         return self.storage.delete_prefix(f"{self.PREFIX}/").deleted
 
     def clear(self, key: str) -> None:
