@@ -1,8 +1,8 @@
-#!/bin/bash 
+#!/bin/bash
 cur=$(git rev-parse --abbrev-ref HEAD)
-git checkout master 
-git push origin master --tags 
+git checkout 4.x
+git push origin 4.x --tags
 git checkout stable
-git merge master
+git merge 4.x
 git push origin stable
 git checkout $cur
