@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import time
 
 import pytest
@@ -14,10 +16,11 @@ from limits.storage import (
     RedisClusterStorage,
     RedisSentinelStorage,
     RedisStorage,
+    SlidingWindowCounterSupport,
     Storage,
     storage_from_string,
 )
-from limits.strategies import MovingWindowRateLimiter
+from limits.strategies import MovingWindowRateLimiter, SlidingWindowCounterRateLimiter
 from tests.utils import fixed_start
 
 
@@ -29,9 +32,9 @@ class TestBaseStorage:
         with pytest.raises(ConfigurationError):
             storage_from_string(uri, **args)
 
-    def test_pluggable_storage_no_moving_window(self):
+    def test_pluggable_storage_fixed_only(self):
         class MyStorage(Storage):
-            STORAGE_SCHEME = ["mystorage"]
+            STORAGE_SCHEME = ["mystorage+fixed"]
 
             @property
             def base_exceptions(self):
@@ -55,14 +58,16 @@ class TestBaseStorage:
             def clear(self):
                 return
 
-        storage = storage_from_string("mystorage://")
+        storage = storage_from_string("mystorage+fixed://")
         assert isinstance(storage, MyStorage)
         with pytest.raises(NotImplementedError):
             MovingWindowRateLimiter(storage)
+        with pytest.raises(NotImplementedError):
+            SlidingWindowCounterRateLimiter(storage)
 
     def test_pluggable_storage_moving_window(self):
-        class MyStorage(Storage):
-            STORAGE_SCHEME = ["mystorage"]
+        class MyStorage(Storage, MovingWindowSupport):
+            STORAGE_SCHEME = ["mystorage+moving"]
 
             @property
             def base_exceptions(self):
@@ -92,10 +97,50 @@ class TestBaseStorage:
             def get_moving_window(self, *a, **k):
                 return (time.time(), 1)
 
-        storage = storage_from_string("mystorage://")
+        storage = storage_from_string("mystorage+moving://")
         assert isinstance(storage, MyStorage)
         MovingWindowRateLimiter(storage)
 
+    def test_pluggable_storage_sliding_window_counter(self):
+        class MyStorage(Storage, SlidingWindowCounterSupport):
+            STORAGE_SCHEME = ["mystorage+sliding"]
+
+            @property
+            def base_exceptions(self):
+                return ValueError
+
+            def incr(self, key, expiry, elastic_expiry=False):
+                return
+
+            def get(self, key):
+                return 0
+
+            def get_expiry(self, key):
+                return time.time()
+
+            def reset(self):
+                return
+
+            def check(self):
+                return
+
+            def clear(self):
+                return
+
+            def acquire_sliding_window_entry(
+                self, key: str, limit: int, expiry: int, amount: int = 1
+            ) -> bool:
+                pass
+
+            def get_sliding_window(
+                self, key: str, expiry: int
+            ) -> tuple[int, float, int, float]:
+                pass
+
+        storage = storage_from_string("mystorage+sliding://")
+        assert isinstance(storage, MyStorage)
+        SlidingWindowCounterRateLimiter(storage)
+
 
 @pytest.mark.parametrize(
     "uri, args, expected_instance, fixture",
@@ -222,13 +267,28 @@ class TestConcreteStorages:
     @fixed_start
     def test_expiry_acquire_entry(self, uri, args, expected_instance, fixture):
         if not issubclass(expected_instance, MovingWindowSupport):
-            pytest.skip("%s does not support acquire entry" % expected_instance)
+            pytest.skip(f"{expected_instance} does not support acquire entry")
         storage = storage_from_string(uri, **args)
         limit = RateLimitItemPerSecond(1)
         assert storage.acquire_entry(limit.key_for(), limit.amount, limit.get_expiry())
         time.sleep(1.1)
         assert storage.get(limit.key_for()) == 0
 
+    @fixed_start
+    def test_expiry_acquire_sliding_window_entry(
+        self, uri, args, expected_instance, fixture
+    ):
+        if not issubclass(expected_instance, SlidingWindowCounterSupport):
+            pytest.skip(f"{expected_instance} does not support acquire entry")
+        storage = storage_from_string(uri, **args)
+        limit = RateLimitItemPerSecond(1)
+        assert storage.acquire_sliding_window_entry(
+            limit.key_for(), limit.amount, limit.get_expiry()
+        )
+        assert storage.get_sliding_window(limit.key_for(), limit.get_expiry())[
+            -1
+        ] == pytest.approx(2, abs=1e2)
+
     def test_incr_custom_amount(self, uri, args, expected_instance, fixture):
         storage = storage_from_string(uri, **args)
         limit = RateLimitItemPerMinute(1)
@@ -237,7 +297,7 @@ class TestConcreteStorages:
 
     def test_acquire_entry_custom_amount(self, uri, args, expected_instance, fixture):
         if not issubclass(expected_instance, MovingWindowSupport):
-            pytest.skip("%s does not support acquire entry" % expected_instance)
+            pytest.skip(f"{expected_instance} does not support acquire entry")
         storage = storage_from_string(uri, **args)
         limit = RateLimitItemPerMinute(10)
         assert not storage.acquire_entry(
@@ -275,7 +335,7 @@ class TestConcreteStorages:
 
 @pytest.mark.parametrize("wrap_exceptions", (True, False))
 class TestStorageErrors:
-    class MyStorage(Storage, MovingWindowSupport):
+    class MyStorage(Storage, MovingWindowSupport, SlidingWindowCounterSupport):
         STORAGE_SCHEME = ["mystorage"]
 
         class MyError(Exception):
@@ -309,6 +369,16 @@ class TestStorageErrors:
         def get_moving_window(self, key, limit, expiry):
             raise self.MyError()
 
+        def acquire_sliding_window_entry(
+            self, key: str, limit: int, expiry: int, amount: int = 1
+        ) -> bool:
+            raise self.MyError()
+
+        def get_sliding_window(
+            self, key: str, expiry: int
+        ) -> tuple[int, float, int, float]:
+            raise self.MyError()
+
     def assert_exception(self, exc, wrap_exceptions):
         if wrap_exceptions:
             assert isinstance(exc, StorageError)
@@ -363,3 +433,15 @@ class TestStorageErrors:
             self.MyStorage(wrap_exceptions=wrap_exceptions).get_moving_window("", 1, 1)
 
         self.assert_exception(exc.value, wrap_exceptions)
+
+    def test_acquire_sliding_entry_exception(self, wrap_exceptions):
+        with pytest.raises(Exception) as exc:
+            self.MyStorage(
+                wrap_exceptions=wrap_exceptions
+            ).acquire_sliding_window_entry("", 1, 1)
+        self.assert_exception(exc.value, wrap_exceptions)
+
+    def test_get_sliding_window_exception(self, wrap_exceptions):
+        with pytest.raises(Exception) as exc:
+            self.MyStorage(wrap_exceptions=wrap_exceptions).get_sliding_window("", 1)
+        self.assert_exception(exc.value, wrap_exceptions)
